if (! suppressWarnings(require(nwsPro, quietly=TRUE)))
  library(nws)
library(grid)
options(device='X11')
grid.newpage()
ws <- netWorkSpace(Sys.getenv('PF_WORKSPACE'))
nwsStore(ws, 'par', 'ready')
ignore <- nwsFind(ws, 'go')
source('pportfolio.R')
ignore <- grid.locator()
